#!/bin/bash

# =========================================
# /home/pi/nest-api/get_nest.sh
# V1.00 Roland@Breedveld.net
# =========================================
# based on : https://github.com/gboudreau/nest-api
# =========================================
#
# Create in Domoticz virtual Devices:
# for Temp     : Temperature LaCross TX3 
# for Hum      : Humidity LaCross TX3 
# for SetPoint : Thermostat SetPoint
# for ECO Mode : a regular Light/Switch and change the icon tosomething nice
# for Heat     : a regular Light/Switch and change the icon tosomething nice
# note the idx nrs, as find in the devices tab, and change them below in this get_nest.sh script
#        TYPE=SETPOINT
#        IDX=492   <<< change this as example for the SETPOINT to your idx
#        note you have to change them twice for HEAT!
#
# edit n Domoticz the ECO Mode switch:
#    On  Action: script:///usr/bin/php /home/pi/nest-api/set_nest_eco_mode.php
#    Off Action: script:///usr/bin/php /home/pi/nest-api/unset_nest_eco_mode.php
#
# Add dzVents script, see example file :Setpoint device is called "Nest Setpoint"
#
# Add the following cron-entry: (crontab -e)
# */5 * * * * /home/pi/nest-api/get_nest.sh >/dev/null 2>&1
#
# if you use a different path, you should change it a some places like here:

cd /home/pi/nest-api

TARGET_SET=0
php get_nest.php| while read LINE
do
  VALUE="$(echo ${LINE}|awk '{print $2}'|sed 's/,$//;s/\"//g')"
  if [ ! -z "$(echo ${VALUE}|grep [0-9])" ]
  then
    VALUE="$(echo ${VALUE}|awk '{print sprintf("%.1f",$1)}')"
  fi
  case "$(echo ${LINE}|awk '{print $1}')" in
    '"target":')
      TARGET_SET=1
      # 1st temp is normaltemp, the same after target is the setpoint
      ;;
    '"temperature":')
      if [ "${TARGET_SET}" == "1" ]
      then
        TYPE=SETPOINT
        IDX=492
      else
        TYPE=TEMP
        IDX=488
      fi
      ;;
    '"humidity":')
      TYPE=HUMIDITY
      IDX=490
      ;;
    '"eco_mode":')
      TYPE=ECOMODE
      IDX=491
      if [ "${VALUE}" == "manual-eco" ]
      then
        VALUE="On"
      else
        VALUE="Off"
      fi
      ;;
    '"heat":')
      if [ "${VALUE}" == "true" ]
      then
        TYPE=HEAT
        IDX=487 
        VALUE="On"
      fi
      if [ "${VALUE}" == "false" ]
      then
        TYPE=HEAT
        IDX=487 
        VALUE="Off"
      fi
      ;;
    *)
      IDX=""
      ;;
  esac

  if [ ! -z "${IDX}" ]
  then
    if [ "${TYPE}" == "TEMP" ]
    then
      curl -X GET "http://127.0.0.1:8080/json.htm?type=command&param=udevice&idx=${IDX}&nvalue=0&svalue=${VALUE}" >/dev/null 2>&1
      echo "Update ${TYPE} to $VALUE"
    fi
    if [ "${TYPE}" == "HUMIDITY" ]
    then
      curl -X GET "http://127.0.0.1:8080/json.htm?type=command&param=udevice&idx=${IDX}&nvalue=${VALUE}&svalue=0" >/dev/null 2>&1
      echo "Update ${TYPE} to $VALUE"
    fi
    if [ "${TYPE}" == "SETPOINT" ]
    then
      CURRENT=$(curl -X GET "http://127.0.0.1:8080/json.htm?type=devices&rid=${IDX}" 2>/dev/null|grep '"SetPoint" : '|sed 's/\"//g;s/,$//'|awk '{print sprintf("%.1f",$3)}')
      if [ "${CURRENT}" != "${VALUE}" ]
      then
        curl -X GET "http://127.0.0.1:8080/json.htm?type=setused&idx=492&setpoint=${VALUE}&used=true" >/dev/null 2>&1
        echo "Update ${TYPE} to $VALUE"
      fi
    fi
    if [ "${VALUE}" == "On" ]
    then
      if curl -X GET "http://127.0.0.1:8080/json.htm?type=devices&rid=${IDX}" 2>/dev/null|grep Status|grep Off >/dev/null 2>&1
      then
        curl -X GET "http://127.0.0.1:8080/json.htm?type=command&param=switchlight&idx=${IDX}&switchcmd=${VALUE}" >/dev/null 2>&1
        echo "Update ${TYPE} state to ${VALUE}"
      fi
    fi
    if [ "${VALUE}" == "Off" ]
    then
      if curl -X GET "http://127.0.0.1:8080/json.htm?type=devices&rid=${IDX}" 2>/dev/null|grep Status|grep On >/dev/null 2>&1
      then
        curl -X GET "http://127.0.0.1:8080/json.htm?type=command&param=switchlight&idx=${IDX}&switchcmd=${VALUE}" >/dev/null 2>&1
        echo "Update ${TYPE} state to ${VALUE}"
      fi
    fi
  fi
done

